@@ -128,6 +128,17 @@ M_cholmod_aat(CHM_SP A, int *fset, size_t fsize,
     return fun(A, fset, fsize, mode, Common);
 }
 
+int attribute_hidden
+M_cholmod_band_inplace(CHM_SP A, int k1, int k2, int mode,
+		       CHM_CM Common)
+{
+    static int(*fun)(CHM_SP,int,int,int,CHM_CM) = NULL;
+    if (fun == NULL)
+	fun = (int(*)(CHM_SP,int,int,int,CHM_CM))
+	    R_GetCCallable("Matrix", "cholmod_l_band_inplace");
+    return fun(A, k1, k2, mode, Common);
+}
+
 CHM_SP attribute_hidden
 M_cholmod_add(CHM_SP A, CHM_SP B,
 	      double alpha[2], double beta[2], int values,
@@ -507,11 +518,10 @@ M_R_cholmod_error(int status, const char *file, int line, const char *message)
 /* NB: keep in sync with R_cholmod_error(), ../../src/chm_common.c */
 
     if(status < 0) {
-/* Note: Matrix itself here calls
- *	cholmod_defaults(&c);/* <--- restore defaults, as we will not be able to ..
- *
- *  Consider defining your own error handler, *and* possibly restoring *your* version
- *  of the cholmod_common that *you* use.
+/* Note: Matrix itself uses CHM_set_common_env, CHM_store_common 
+ *   and CHM_restore_common to preserve settings through error calls.
+ *  Consider defining your own error handler, *and* possibly restoring
+ *  *your* version of the cholmod_common that *you* use.
  */
 	error("Cholmod error '%s' at file:%s, line %d", message, file, line);
     }
